NLSL: physcn.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Modules | Variables
physcn.f90 File Reference

Go to the source code of this file.

## Modules
module | physcn

## Variables
double precision, parameter | physcn::ge =2.002 319 304 3737 D0
double precision, parameter | physcn::betae =927.400 899 D-23
double precision, parameter | physcn::hbar =1.054 571 596 D-27
double precision, parameter | physcn::gammae =1.760 859 794 D7
double precision, parameter | physcn::kb =1.380 6503 D-16